#
# spec file for package qelectrotech
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qelectrotech
Version:        0.4
Release:        6.4
Summary:        Application to design electric diagrams
License:        GPL-2.0+ and CC-BY-3.0
Group:          Productivity/Scientific/Electronics
Url:            http://qelectrotech.org/
Source0:        http://download.tuxfamily.org/qet/tags/20150220/%{name}-%{version}-src.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
BuildRequires:  update-desktop-files
Requires(post): desktop-file-utils
Requires(post): shared-mime-info
Requires(postun): desktop-file-utils
Requires(postun): shared-mime-info
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
QElectroTech is a Qt4 application to design electric diagrams. It uses XML
files for elements and diagrams, and includes both a diagram editor and an
element editor.

%prep
%setup -q -n %{name}-%{version}-src

# Fix compilation and installation paths
sed -e s,/usr/local/,%{_prefix}/, \
    -e /QET_LICENSE_PATH/s,'doc/,'share/doc/packages/, \
    -e /QET_MIME/s,../,, \
    -e /QET_MAN_PATH/s,'man/','share/man/', \
    -i qelectrotech.pro

# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/g" sources/aboutqet.cpp
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/g" sources/aboutqet.cpp

%build
qmake QMAKE_CXXFLAGS+="%{optflags}" -config debug qelectrotech.pro

make %{?_smp_mflags}

%install
%make_install INSTALL_ROOT=%{buildroot}

# Fix desktop file
%suse_update_desktop_file -r qelectrotech "Education;Engineering"

%fdupes -s %{buildroot}

%find_lang %{name} --with-qt --with-man --all-name

%post
%mime_database_post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc CREDIT ChangeLog ELEMENTS.LICENSE LICENSE README
%{_bindir}/qelectrotech
%dir %{_datadir}/appdata
%{_datadir}/appdata/qelectrotech.appdata.xml
%{_datadir}/applications/qelectrotech.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%dir %{_mandir}/be
%dir %{_mandir}/fr.ISO8859-1
%dir %{_mandir}/fr.UTF-8
%doc %{_mandir}/man1/qelectrotech.1%{ext_man}
%{_datadir}/mime/application/x-qet-element.xml
%{_datadir}/mime/application/x-qet-project.xml
%{_datadir}/mime/application/x-qet-titleblock.xml
%{_datadir}/mime/packages/qelectrotech.xml
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%{_datadir}/mimelnk/application/x-qet-element.desktop
%{_datadir}/mimelnk/application/x-qet-project.desktop
%{_datadir}/mimelnk/application/x-qet-titleblock.desktop
%dir %{_datadir}/qelectrotech
%dir %{_datadir}/qelectrotech/lang
%{_datadir}/qelectrotech/elements/
%{_datadir}/qelectrotech/examples/
%{_datadir}/qelectrotech/titleblocks/

%changelog
* Tue Mar  3 2015 benoit.monin@gmx.fr
- update to version 0.4:
  * In the official collection, there are now 2298 elements, and
    376 categories for a total of 2674 files
  * We have removed the flag '-fno-ipa-sra "This settled the
    compilation problems on Mac OS X and FreeBSD clang
  * The official collection has been redesigned, through the work
    of Nuri a new structure is in place
  * A menu has been added, allowing you to change the application
    language
  * we added a summary creation tool
  * Added button "export the nomenclature" transforms data from
    diagrams to CSV file for spreadsheet
  * Arun wrote a detailed manual and quality in English
  * New tools have been added, they can create mechanical
    connections and draw cabinets, desks, junction boxes, or areas
    on the schematic (line tool, rectangle, ellipse, polygon type:
    respect for style dashes)
  * An aid in positioning cross, drawing, was added
  * The locked state images and basic forms (basic shapes) is now
    stored in the project
  * The "control" during the movement of an element, text field
    disables snapping to the grid, for free positioning
  * It is now possible to choose the background folios in white or
    gray
  * Add supports trackpad gestures (multitouch)
  * The dates of the cartridges are now using the short system date
    and date format according to the language detected setting in
    the OS
  * We take advantage of the transition to standard C ++ 11, and a
    big cleanup in the code was done
  * The undo action or redo the undo stack are now animated
    graphically
  * When the action save, save as, the status bar displays the name
    and path of the backup job
  * Qet is now able to come to load a style sheet (stylesheet)
    directly from the conf directory
  * A DXF export has been added, the entire project folios can be
    exported in this format
  * Added reports folio, Cross references
  * Added a variable font size on the text of conductors
  * Added new properties to all conductors at the same potential,
    even through referrals
  * When several conductors have the same value potential
    equalization, it is not useful to display on all conductors
  * Added button to activates the automatic connection of the
    conductors of the element when moving it
  * Numbering rules are now available for the entire project
  * Qet detects the Windows version and applies the appropriate
    graphic style, depending on the version of Windows.
- update source URL
- remove buildRequires desktop-file-utils
- add buildRequires update-desktop-files
- use suse_update_desktop_file to set desktop categories
- add belgium man page to the package
* Sun Oct 27 2013 asterios.dramis@gmail.com
- Update to version 0.3:
  * See http://qelectrotech.org/news for changes.
* Mon Jul  8 2013 asterios.dramis@gmail.com
- Update to version 0.3b:
  * See http://qelectrotech.org/wiki/en/doc/changelog_0.3a_0.3b for changes.
- Removed fix_paths.patch and instead added a fix for qelectrotech.pro inside
  the spec file.
- Added desktop_database_post/desktop_database_postun entries since the package
  defines a MIME handler.
- Added icon_theme_cache_post/icon_theme_cache_postun entries since the package
  installs icons in an icon dir. Added hicolor-icon-theme as build requirement
  for this.
* Mon Jul 16 2012 asterios.dramis@gmail.com
- Fixed compilation in Factory (fixed post-build-check error "directories not
  owned by a package").
- Use desktop-file-utils instead of the %%suse_update_desktop_file macro for
  editing the desktop file (removed update-desktop-files build dependency and
  added desktop-file-utils for this).
* Tue May 15 2012 asterios.dramis@gmail.com
- Update to version 0.3a:
  * See http://qelectrotech.org/wiki/en/doc/changelog_0.22_0.3a for changes.
- Fixed rpmlint warning "script-without-shebang".
- Rebased fix_paths.patch to apply cleanly.
* Sat Aug 13 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changed License: to GPL-2.0+ and CC-BY-3.0.
* Sat Aug 13 2011 asterios.dramis@gmail.com
- Initial rpm release (version 0.22).
- Added a patch (fix_paths.patch) to fix compilation and installation paths.
